summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNeal H. Walfield <neal@pep.foundation>2022-10-05 13:28:38 +0200
committerNeal H. Walfield <neal@pep.foundation>2022-10-30 07:23:13 +0100
commit3f367e8a303646704976ed212254ec5b91c7cff1 (patch)
tree8b88fd199104747553a1a2174689da797ac3f71e
parent8826fe15d4885f495c038e6b9c0ca7666b63025e (diff)
sq: Rename --signer-cert, etc. to --signer-file
- Rename `--recipient-cert` to `--recipient-file`, `--signer-cert` to `--signer-file`, and `--certificate` to `--certificate-file`. - This rename makes it clearer that the argument is a file containing a certificate. - See #933.
-rw-r--r--sq/sq-subplot.md40
-rw-r--r--sq/sq-usage.md26
-rw-r--r--sq/src/sq_cli/decrypt.rs4
-rw-r--r--sq/src/sq_cli/encrypt.rs6
-rw-r--r--sq/src/sq_cli/revoke.rs16
-rw-r--r--sq/src/sq_cli/verify.rs6
-rw-r--r--sq/tests/sq-revoke.rs8
-rw-r--r--sq/tests/sq-sign.rs40
8 files changed, 73 insertions, 73 deletions
diff --git a/sq/sq-subplot.md b/sq/sq-subplot.md
index c6dedb1e..4b32f156 100644
--- a/sq/sq-subplot.md
+++ b/sq/sq-subplot.md
@@ -996,7 +996,7 @@ given an installed sq
given file hello.txt
when I run sq key generate --export key.pgp
when I run sq key extract-cert -o cert.pgp key.pgp
-when I run sq encrypt --recipient-cert cert.pgp hello.txt
+when I run sq encrypt --recipient-file cert.pgp hello.txt
then stdout contains "-----BEGIN PGP MESSAGE-----"
then stdout doesn't contain "hello, world"
~~~
@@ -1015,7 +1015,7 @@ given an installed sq
given file hello.txt
when I run sq key generate --export key.pgp
when I run sq key extract-cert -o cert.pgp key.pgp
-when I run sq encrypt --binary --recipient-cert cert.pgp hello.txt
+when I run sq encrypt --binary --recipient-file cert.pgp hello.txt
then stdout doesn't contain "-----BEGIN PGP MESSAGE-----"
then stdout doesn't contain "hello, world"
~~~
@@ -1037,7 +1037,7 @@ given an installed sq
given file hello.txt
when I run sq key generate --export key.pgp
when I run sq key extract-cert -o cert.pgp key.pgp
-when I run sq encrypt -o x.pgp --recipient-cert cert.pgp hello.txt
+when I run sq encrypt -o x.pgp --recipient-file cert.pgp hello.txt
when I run sq decrypt -o output.txt --recipient-file key.pgp x.pgp
then files hello.txt and output.txt match
~~~
@@ -1056,7 +1056,7 @@ when I run sq key extract-cert -o alice-cert.pgp alice.pgp
when I run sq key generate --export bob.pgp
when I run sq key extract-cert -o bob-cert.pgp bob.pgp
-when I run sq encrypt --recipient-cert alice-cert.pgp --recipient-cert bob-cert.pgp hello.txt -o x.pgp
+when I run sq encrypt --recipient-file alice-cert.pgp --recipient-file bob-cert.pgp hello.txt -o x.pgp
when I run sq decrypt --recipient-file alice.pgp -o alice.txt x.pgp
then files hello.txt and alice.txt match
@@ -1077,9 +1077,9 @@ given file hello.txt
when I run sq key generate --export alice.pgp
when I run sq key extract-cert -o alice-cert.pgp alice.pgp
-when I run sq encrypt --recipient-cert alice-cert.pgp --signer-file alice.pgp hello.txt -o x.pgp
+when I run sq encrypt --recipient-file alice-cert.pgp --signer-file alice.pgp hello.txt -o x.pgp
-when I run sq decrypt --recipient-file alice.pgp -o alice.txt x.pgp --signer-cert alice-cert.pgp
+when I run sq decrypt --recipient-file alice.pgp -o alice.txt x.pgp --signer-file alice-cert.pgp
then files hello.txt and alice.txt match
~~~
@@ -1098,9 +1098,9 @@ when I run sq key extract-cert -o alice-cert.pgp alice.pgp
when I run sq key generate --export bob.pgp
when I run sq key extract-cert -o bob-cert.pgp bob.pgp
-when I run sq encrypt --recipient-cert alice-cert.pgp --signer-file alice.pgp hello.txt -o x.pgp
+when I run sq encrypt --recipient-file alice-cert.pgp --signer-file alice.pgp hello.txt -o x.pgp
-when I try to run sq decrypt --recipient-file alice.pgp -o alice.txt x.pgp --signer-cert bob-cert.pgp
+when I try to run sq decrypt --recipient-file alice.pgp -o alice.txt x.pgp --signer-file bob-cert.pgp
then exit code is 1
then files alice.txt and empty match
~~~
@@ -1217,7 +1217,7 @@ given file hello.txt
when I run sq key generate --export key.pgp
when I run sq key extract-cert key.pgp -o cert.pgp
when I run sq sign --signer-file key.pgp hello.txt -o signed.txt
-when I run sq verify --signer-cert cert.pgp signed.txt
+when I run sq verify --signer-file cert.pgp signed.txt
then stdout contains "hello, world"
~~~
@@ -1239,13 +1239,13 @@ when I run sq key generate --userid Bob --export bob.pgp
when I run sq key extract-cert bob.pgp -o bob-cert.pgp
when I run sq sign --signer-file alice.pgp hello.txt -o signed1.txt
-when I try to run sq verify --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp --signatures=2 signed1.txt
+when I try to run sq verify --signer-file alice-cert.pgp --signer-file bob-cert.pgp --signatures=2 signed1.txt
then exit code is 1
when I run sq sign --append --signer-file bob.pgp signed1.txt -o signed2.txt
-when I run sq verify --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp --signatures=1 signed2.txt
+when I run sq verify --signer-file alice-cert.pgp --signer-file bob-cert.pgp --signatures=1 signed2.txt
then stdout contains "hello, world"
-when I run sq verify --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp --signatures=2 signed2.txt
+when I run sq verify --signer-file alice-cert.pgp --signer-file bob-cert.pgp --signatures=2 signed2.txt
then stdout contains "hello, world"
~~~
@@ -1267,7 +1267,7 @@ when I run sq key generate --export key.pgp
when I run sq key extract-cert key.pgp -o cert.pgp
when I run sq sign --signer-file key.pgp hello.txt -o signed.txt
when I run bash sed-in-place 3d signed.txt
-when I try to run sq verify --signer-cert cert.pgp signed.txt
+when I try to run sq verify --signer-file cert.pgp signed.txt
then command fails
~~~
@@ -1296,7 +1296,7 @@ when I run sq sign --cleartext-signature --signer-file key.pgp hello.txt -o sign
then file signed.txt contains "-----BEGIN PGP SIGNED MESSAGE-----"
then file signed.txt contains "hello, world"
then file signed.txt contains "-----END PGP SIGNATURE-----"
-when I run sq verify --signer-cert cert.pgp signed.txt
+when I run sq verify --signer-file cert.pgp signed.txt
then stdout contains "hello, world"
~~~
@@ -1315,7 +1315,7 @@ when I run sq key extract-cert key.pgp -o cert.pgp
when I run sq sign --cleartext-signature --signer-file key.pgp hello.txt -o signed.txt
when I run bash sed-in-place s/hello/HELLO/ signed.txt
-when I try to run sq verify --signer-cert cert.pgp signed.txt
+when I try to run sq verify --signer-file cert.pgp signed.txt
then exit code is 1
~~~
@@ -1333,7 +1333,7 @@ when I run sq key extract-cert key.pgp -o cert.pgp
when I run sq sign --detached --signer-file key.pgp hello.txt -o sig.txt
then file sig.txt contains "-----BEGIN PGP SIGNATURE-----"
then file sig.txt contains "-----END PGP SIGNATURE-----"
-when I run sq verify --detached=sig.txt --signer-cert=cert.pgp hello.txt
+when I run sq verify --detached=sig.txt --signer-file=cert.pgp hello.txt
then stdout doesn't contain "hello, world"
then exit code is 0
~~~
@@ -1353,7 +1353,7 @@ when I run sq key extract-cert key.pgp -o cert.pgp
when I run sq sign --detached --signer-file key.pgp hello.txt -o sig.txt
when I run bash sed-in-place s/hello/HELLO/ hello.txt
-when I try to run sq verify --detached=sig.txt --signer-cert=cert.pgp hello.txt
+when I try to run sq verify --detached=sig.txt --signer-file=cert.pgp hello.txt
then exit code is 1
~~~
@@ -1373,7 +1373,7 @@ when I run sq key extract-cert bob.pgp -o bob-cert.pgp
when I run sq sign --signer-file alice.pgp hello.txt -o signed1.txt
when I run sq sign --signer-file bob.pgp --append signed1.txt -o signed2.txt
-when I run sq verify signed2.txt --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp
+when I run sq verify signed2.txt --signer-file alice-cert.pgp --signer-file bob-cert.pgp
then stdout contains "hello, world"
then stderr contains "2 good signatures"
~~~
@@ -1394,7 +1394,7 @@ when I run sq key extract-cert bob.pgp -o bob-cert.pgp
when I run sq sign --signer-file alice.pgp hello.txt -o signed1.txt
when I run sq sign --signer-file bob.pgp hello.txt -o signed2.txt
when I run sq sign --merge=signed2.txt signed1.txt -o merged.txt
-when I run sq verify merged.txt --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp
+when I run sq verify merged.txt --signer-file alice-cert.pgp --signer-file bob-cert.pgp
then stdout contains "hello, world"
then stderr contains "2 good signatures"
~~~
@@ -1414,7 +1414,7 @@ when I run sq key extract-cert bob.pgp -o bob-cert.pgp
when I run sq sign --signer-file alice.pgp hello.txt -o signed.txt
when I run sq sign --signer-file bob.pgp --notarize signed.txt -o notarized.txt
-when I run sq verify notarized.txt --signer-cert alice-cert.pgp --signer-cert bob-cert.pgp
+when I run sq verify notarized.txt --signer-file alice-cert.pgp --signer-file bob-cert.pgp
then stdout contains "hello, world"
then stderr contains "Good level 1 notarization from"
then stderr contains "2 good signatures"
diff --git a/sq/sq-usage.md b/sq/sq-usage.md
index 87ecf0f4..3e159975 100644
--- a/sq/sq-usage.md
+++ b/sq/sq-usage.md
@@ -134,7 +134,7 @@ OPTIONS:
--private-key-store <KEY_STORE>
Provides parameters for private key store
- --recipient-cert <CERT_RING_FILE>
+ --recipient-file <CERT_RING_FILE>
Encrypts to all certificates in CERT_RING_FILE
-s, --symmetric
@@ -155,10 +155,10 @@ OPTIONS:
EXAMPLES:
# Encrypt a file using a certificate
-$ sq encrypt --recipient-cert romeo.pgp message.txt
+$ sq encrypt --recipient-file romeo.pgp message.txt
# Encrypt a file creating a signature in the process
-$ sq encrypt --recipient-cert romeo.pgp --signer-file juliet.pgp message.txt
+$ sq encrypt --recipient-file romeo.pgp --signer-file juliet.pgp message.txt
# Encrypt a file using a password
$ sq encrypt --symmetric message.txt
@@ -221,7 +221,7 @@ OPTIONS:
--session-key <SESSION-KEY>
Decrypts an encrypted message using SESSION-KEY
- --signer-cert <CERT_FILE>
+ --signer-file <CERT_FILE>
Verifies signatures using the certificates in CERT_FILE
-x, --hex
@@ -233,7 +233,7 @@ EXAMPLES:
$ sq decrypt --recipient-file juliet.pgp ciphertext.pgp
# Decrypt a file verifying signatures
-$ sq decrypt --recipient-file juliet.pgp --signer-cert romeo.pgp ciphertext.pgp
+$ sq decrypt --recipient-file juliet.pgp --signer-file romeo.pgp ciphertext.pgp
# Decrypt a file using a password
$ sq decrypt ciphertext.pgp
@@ -355,16 +355,16 @@ OPTIONS:
-o, --output <FILE>
Writes to FILE or stdout if omitted
- --signer-cert <CERT_FILE>
+ --signer-file <CERT_FILE>
Verifies signatures using the certificate in CERT_FILE
EXAMPLES:
# Verify a signed message
-$ sq verify --signer-cert juliet.pgp signed-message.pgp
+$ sq verify --signer-file juliet.pgp signed-message.pgp
# Verify a detached message
-$ sq verify --signer-cert juliet.pgp --detached message.sig message.txt
+$ sq verify --signer-file juliet.pgp --detached message.sig message.txt
```
## Subcommand sq key
@@ -1909,11 +1909,11 @@ SUBCOMMANDS:
EXAMPLES:
# Revoke a certificate.
-$ sq revoke certificate --time 20220101 --certificate juliet.pgp \
+$ sq revoke certificate --time 20220101 --cert-file juliet.pgp \
compromised "My parents went through my things, and found my backup."
# Revoke a User ID.
-$ sq revoke userid --time 20220101 --certificate juliet.pgp \
+$ sq revoke userid --time 20220101 --cert-file juliet.pgp \
"Juliet <juliet@capuleti.it>" retired "I've left the family."
```
@@ -1984,7 +1984,7 @@ OPTIONS:
-B, --binary
Emits binary data
- --certificate <FILE>
+ --certificate-file <FILE>
Reads the certificate to revoke from FILE or stdin, if omitted. It
is an error for the file to contain more than one certificate.
@@ -2081,7 +2081,7 @@ OPTIONS:
-B, --binary
Emits binary data
- --certificate <FILE>
+ --certificate-file <FILE>
Reads the certificate containing the subkey to revoke from FILE or
stdin, if omitted. It is an error for the file to contain more than
one certificate.
@@ -2168,7 +2168,7 @@ OPTIONS:
-B, --binary
Emits binary data
- --certificate <CERT_FILE>
+ --certificate-file <CERT_FILE>
Reads the certificate to revoke from CERT_FILE or stdin, if omitted.
It is an error for the file to contain more than one certificate.
diff --git a/sq/src/sq_cli/decrypt.rs b/sq/src/sq_cli/decrypt.rs
index d185193a..3c2a4766 100644
--- a/sq/src/sq_cli/decrypt.rs
+++ b/sq/src/sq_cli/decrypt.rs
@@ -34,7 +34,7 @@ The converse operation is \"sq encrypt\".
$ sq decrypt --recipient-file juliet.pgp ciphertext.pgp
# Decrypt a file verifying signatures
-$ sq decrypt --recipient-file juliet.pgp --signer-cert romeo.pgp ciphertext.pgp
+$ sq decrypt --recipient-file juliet.pgp --signer-file romeo.pgp ciphertext.pgp
# Decrypt a file using a password
$ sq decrypt ciphertext.pgp
@@ -58,7 +58,7 @@ pub struct Command {
)]
pub signatures: Option<usize>,
#[clap(
- long = "signer-cert",
+ long = "signer-file",
value_name = "CERT_FILE",
help = "Verifies signatures using the certificates in CERT_FILE",
)]
diff --git a/sq/src/sq_cli/encrypt.rs b/sq/src/sq_cli/encrypt.rs
index 4fc0e839..a90a9495 100644
--- a/sq/src/sq_cli/encrypt.rs
+++ b/sq/src/sq_cli/encrypt.rs
@@ -18,10 +18,10 @@ The converse operation is \"sq decrypt\".
"EXAMPLES:
# Encrypt a file using a certificate
-$ sq encrypt --recipient-cert romeo.pgp message.txt
+$ sq encrypt --recipient-file romeo.pgp message.txt
# Encrypt a file creating a signature in the process
-$ sq encrypt --recipient-cert romeo.pgp --signer-file juliet.pgp message.txt
+$ sq encrypt --recipient-file romeo.pgp --signer-file juliet.pgp message.txt
# Encrypt a file using a password
$ sq encrypt --symmetric message.txt
@@ -37,7 +37,7 @@ pub struct Command {
)]
pub binary: bool,
#[clap(
- long = "recipient-cert",
+ long = "recipient-file",
value_name = "CERT_RING_FILE",
multiple_occurrences = true,
help = "Encrypts to all certificates in CERT_RING_FILE",
diff --git a/sq/src/sq_cli/revoke.rs b/sq/src/sq_cli/revoke.rs
index 558d5bfe..13d2ddfc 100644
--- a/sq/src/sq_cli/revoke.rs
+++ b/sq/src/sq_cli/revoke.rs
@@ -35,11 +35,11 @@ certificate to a keyserver.
"EXAMPLES:
# Revoke a certificate.
-$ sq revoke certificate --time 20220101 --certificate juliet.pgp \\
+$ sq revoke certificate --time 20220101 --cert-file juliet.pgp \\
compromised \"My parents went through my things, and found my backup.\"
# Revoke a User ID.
-$ sq revoke userid --time 20220101 --certificate juliet.pgp \\
+$ sq revoke userid --time 20220101 --cert-file juliet.pgp \\
\"Juliet <juliet@capuleti.it>\" retired \"I've left the family.\"
",
subcommand_required = true,
@@ -79,8 +79,8 @@ include a certification-capable key.
pub struct CertificateCommand {
#[clap(
value_name = "FILE",
- long = "certificate",
- alias = "cert",
+ long = "certificate-file",
+ alias = "cert-file",
help = "The certificate to revoke",
long_help =
"Reads the certificate to revoke from FILE or stdin, if omitted. It is \
@@ -225,8 +225,8 @@ must include a certification-capable key.",
pub struct SubkeyCommand {
#[clap(
value_name = "FILE",
- long = "certificate",
- alias = "cert",
+ long = "certificate-file",
+ alias = "cert-file",
help = "The certificate containing the subkey to revoke",
long_help =
"Reads the certificate containing the subkey to revoke from FILE or stdin, \
@@ -359,8 +359,8 @@ include a certification-capable key.",
pub struct UseridCommand {
#[clap(
value_name = "CERT_FILE",
- long = "certificate",
- alias = "cert",
+ long = "certificate-file",
+ alias = "cert-file",
help = "The certificate containing the User ID to revoke",
long_help =
"Reads the certificate to revoke from CERT_FILE or stdin, \
diff --git a/sq/src/sq_cli/verify.rs b/sq/src/sq_cli/verify.rs
index e7ef8606..48d36698 100644
--- a/sq/src/sq_cli/verify.rs
+++ b/sq/src/sq_cli/verify.rs
@@ -31,10 +31,10 @@ signatures, consider using sequoia-sqv.
"EXAMPLES:
# Verify a signed message
-$ sq verify --signer-cert juliet.pgp signed-message.pgp
+$ sq verify --signer-file juliet.pgp signed-message.pgp
# Verify a detached message
-$ sq verify --signer-cert juliet.pgp --detached message.sig message.txt
+$ sq verify --signer-file juliet.pgp --detached message.sig message.txt
",
)]
pub struct Command {
@@ -58,7 +58,7 @@ pub struct Command {
)]
pub signatures: usize,
#[clap(
- long = "signer-cert",
+ long = "signer-file",
value_name = "CERT_FILE",
help = "Verifies signatures using the certificate in CERT_FILE",
)]
diff --git a/sq/tests/sq-sign.rs b/sq/tests/sq-sign.rs
index 0d61e341..a6f08291 100644
--- a/sq/tests/sq-sign.rs
+++ b/sq/tests/sq-sign.rs
@@ -69,7 +69,7 @@ fn sq_sign() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig.to_string_lossy())
.assert()
.success();
@@ -147,7 +147,7 @@ fn sq_sign_with_notations() {
.unwrap()
.args(["--known-notation", "foo"])
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig.to_string_lossy())
.assert()
.success();
@@ -196,7 +196,7 @@ fn sq_sign_append() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -255,14 +255,14 @@ fn sq_sign_append() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig1.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.arg(&*sig1.to_string_lossy())
.assert()
.success();
@@ -323,7 +323,7 @@ fn sq_sign_append_on_compress_then_sign() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -385,7 +385,7 @@ fn sq_sign_append_on_compress_then_sign() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -393,7 +393,7 @@ fn sq_sign_append_on_compress_then_sign() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -432,7 +432,7 @@ fn sq_sign_detached() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.args(["--detached", &sig.to_string_lossy()])
.arg(&artifact("messages/a-cypherpunks-manifesto.txt"))
.assert()
@@ -472,7 +472,7 @@ fn sq_sign_detached_append() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.args(["--detached", &sig.to_string_lossy()])
.arg(&artifact("messages/a-cypherpunks-manifesto.txt"))
.assert()
@@ -523,7 +523,7 @@ fn sq_sign_detached_append() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/dennis-simon-anton.pgp")])
+ .args(["--signer-file", &artifact("keys/dennis-simon-anton.pgp")])
.args(["--detached", &sig.to_string_lossy()])
.arg(&artifact("messages/a-cypherpunks-manifesto.txt"))
.assert()
@@ -532,7 +532,7 @@ fn sq_sign_detached_append() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.args(["--detached", &sig.to_string_lossy()])
.arg(&artifact("messages/a-cypherpunks-manifesto.txt"))
.assert()
@@ -639,21 +639,21 @@ fn sq_sign_append_a_notarization() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/neal.pgp")])
+ .args(["--signer-file", &artifact("keys/neal.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/emmelie-dorothea-dina-samantha-awina-ed25519.pgp")])
+ .args(["--signer-file", &artifact("keys/emmelie-dorothea-dina-samantha-awina-ed25519.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -716,14 +716,14 @@ fn sq_sign_notarize() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/neal.pgp")])
+ .args(["--signer-file", &artifact("keys/neal.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
@@ -798,21 +798,21 @@ fn sq_sign_notarize_a_notarization() {
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/neal.pgp")])
+ .args(["--signer-file", &artifact("keys/neal.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/emmelie-dorothea-dina-samantha-awina-ed25519.pgp")])
+ .args(["--signer-file", &artifact("keys/emmelie-dorothea-dina-samantha-awina-ed25519.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
Command::cargo_bin("sq")
.unwrap()
.arg("verify")
- .args(["--signer-cert", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
+ .args(["--signer-file", &artifact("keys/erika-corinna-daniela-simone-antonia-nistp256.pgp")])
.arg(&*sig0.to_string_lossy())
.assert()
.success();
diff --git a/sq/tests/sq-revoke.rs b/sq/tests/sq-revoke.rs
index 7ea5c7c4..55d255a0 100644
--- a/sq/tests/sq-revoke.rs
+++ b/sq/tests/sq-revoke.rs
@@ -162,7 +162,7 @@ mod integration {
Some(dir)
},
(true, false) => { // third_party && ! stdin
- // sq revoke --certificate cert --revocation-file third-party
+ // sq revoke --cert-file cert --revocation-file third-party
let dir = TempDir::new()?;
let cert_pgp = dir.path().join("cert.pgp");
@@ -170,7 +170,7 @@ mod integration {
file.write_all(&cert)?;
cmd.args([
- "--certificate",
+ "--cert-file",
&*cert_pgp.to_string_lossy()
]);
@@ -192,7 +192,7 @@ mod integration {
None
},
(false, false) => { // ! third_party && ! stdin
// sq revoke --certificate key
let dir = TempDir::new()?;
let key_pgp = dir.path().join("key.pgp");
@@ -200,7 +200,7 @@ mod integration {
file.write_all(&revoker)?;
cmd.args([
- "--certificate",
+ "--cert-file",
&*key_pgp.to_string_lossy()
]);
@@ -192,7 +192,7 @@ mod integration {
},
(false, false) => { // ! third_party && ! stdin
- // sq revoke --certificate key
+ // sq revoke --cert-file key
let dir = TempDir::new()?;
let key_pgp = dir.path().join("key.pgp");